@@ -1,4 +1,7 @@
 package MooseX::Constructor::AllErrors::Role::Meta::Class;
+BEGIN {
+  $MooseX::Constructor::AllErrors::Role::Meta::Class::VERSION = '0.013';
+}
 use Moose::Role;
 
 around _inline_BUILDALL => sub {
@@ -7,9 +10,7 @@ around _inline_BUILDALL => sub {
 
     my @source = $self->$orig(@_);
 
-    my @attrs = grep { defined $_->init_arg }
-        sort { $a->insertion_order <=> $b->insertion_order }
-        $self->get_all_attributes;
+    my @attrs = grep { defined $_->init_arg } $self->get_all_attributes;
 
     my $required = join '', map {
         q{'} . $_->init_arg . q{' => 1,}
@@ -24,7 +25,6 @@ around _inline_BUILDALL => sub {
     } grep { $_->should_coerce } @attrs;
 
     return (
-        @source,
         'my $all_errors = MooseX::Constructor::AllErrors::Error::Constructor->new(',
             'caller => [caller(1)]',
         ');',
